#!/usr/bin/env bash

#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

set -e

SCRIPTDIR=$(cd $(dirname "$0") && pwd)
ROOTDIR="$SCRIPTDIR/../.."

cd $ROOTDIR/tools/travis
export TESTCONTAINERS_RYUK_DISABLED="true"
export ORG_GRADLE_PROJECT_testSetName="REQUIRE_ONLY_DB"

./setupPrereq.sh

cat "$ROOTDIR/tests/src/test/resources/application.conf"

./distDocker.sh

# yet another hack to hit docker rate limits early...
docker pull alpine:3.5

./runTests.sh
